==> anwiba-commons-core-1.0.68-sources.jar: net/anwiba/commons/resource/utilities/IFileExtensions.java <==
/*
 * #%L
 * anwiba commons core
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.resource.utilities;

public interface IFileExtensions {

  public static final String ASC = "asc"; //$NON-NLS-1$
  public static final String BMP = "bmp"; //$NON-NLS-1$
  public static final String BPW = "bpw"; //$NON-NLS-1$
  public static final String DAT = "dat"; //$NON-NLS-1$
  public static final String DGM = "dgm"; //$NON-NLS-1$
  public static final String GFW = "gfw"; //$NON-NLS-1$
  public static final String GIF = "gif"; //$NON-NLS-1$
  public static final String JAR = "jar"; //$NON-NLS-1$
  public static final String JGW = "jgw"; //$NON-NLS-1$
  public static final String JLAYER = "jlayer"; //$NON-NLS-1$
  public static final String JPG = "jpg"; //$NON-NLS-1$
  public static final String JPEG = "jpeg"; //$NON-NLS-1$
  public static final String JPGW = "jpgw"; //$NON-NLS-1$
  public static final String KEY = "key"; //$NON-NLS-1$
  public static final String MAP = "map"; //$NON-NLS-1$
  public static final String MDB = "mdb"; //$NON-NLS-1$
  public static final String PGW = "pgw"; //$NON-NLS-1$
  public static final String PNG = "png"; //$NON-NLS-1$

  public static final String DEF = "def"; //$NON-NLS-1$
  public static final String CPG = "cpg"; //$NON-NLS-1$
  public static final String PRJ = "prj"; //$NON-NLS-1$

  public static final String SHP = "shp"; //$NON-NLS-1$
  public static final String DBF = "dbf"; //$NON-NLS-1$
  public static final String SBN = "sbn"; //$NON-NLS-1$
  public static final String SBX = "sbx"; //$NON-NLS-1$
  public static final String SHI = "shi"; //$NON-NLS-1$
  public static final String SHX = "shx"; //$NON-NLS-1$

  public static final String SDAT = "sdat"; //$NON-NLS-1$
  public static final String SGRD = "sgrd"; //$NON-NLS-1$
  public static final String TFW = "tfw"; //$NON-NLS-1$
  public static final String TIF = "tif"; //$NON-NLS-1$
  public static final String TIFF = "tiff"; //$NON-NLS-1$
  public static final String TIFW = "tifw"; //$NON-NLS-1$
  public static final String WLD = "wld"; //$NON-NLS-1$
  public static final String XYZ = "xyz"; //$NON-NLS-1$
  public static final String ZIP = "zip"; //$NON-NLS-1$
  public static final String FLML = "flml"; //$NON-NLS-1$
  public static final String SQLITE = "sqlite"; //$NON-NLS-1$
  public static final String GPKG = "gpkg"; //$NON-NLS-1$
  public static final String GEOJSON = "geojson"; //$NON-NLS-1$
  public static final String MBTILES = "mbtiles"; //$NON-NLS-1$
  public static final String SQL = "sql"; //$NON-NLS-1$

}

==> anwiba-commons-core-1.0.76-sources.jar: net/anwiba/commons/resource/utilities/IFileExtensions.java <==
/*
 * #%L
 * anwiba commons core
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.resource.utilities;

public interface IFileExtensions {

  public static final String ASC = "asc"; //$NON-NLS-1$
  public static final String BMP = "bmp"; //$NON-NLS-1$
  public static final String BPW = "bpw"; //$NON-NLS-1$
  public static final String DAT = "dat"; //$NON-NLS-1$
  public static final String DGM = "dgm"; //$NON-NLS-1$
  public static final String GFW = "gfw"; //$NON-NLS-1$
  public static final String GIF = "gif"; //$NON-NLS-1$
  public static final String JAR = "jar"; //$NON-NLS-1$
  public static final String JGW = "jgw"; //$NON-NLS-1$
  public static final String JLAYER = "jlayer"; //$NON-NLS-1$
  public static final String JPG = "jpg"; //$NON-NLS-1$
  public static final String JPEG = "jpeg"; //$NON-NLS-1$
  public static final String JPGW = "jpgw"; //$NON-NLS-1$
  public static final String KEY = "key"; //$NON-NLS-1$
  public static final String MAP = "map"; //$NON-NLS-1$
  public static final String MDB = "mdb"; //$NON-NLS-1$
  public static final String PGW = "pgw"; //$NON-NLS-1$
  public static final String PNG = "png"; //$NON-NLS-1$

  public static final String DEF = "def"; //$NON-NLS-1$
  public static final String CPG = "cpg"; //$NON-NLS-1$
  public static final String PRJ = "prj"; //$NON-NLS-1$

  public static final String SHP = "shp"; //$NON-NLS-1$
  public static final String DBF = "dbf"; //$NON-NLS-1$
  public static final String SBN = "sbn"; //$NON-NLS-1$
  public static final String SBX = "sbx"; //$NON-NLS-1$
  public static final String SHI = "shi"; //$NON-NLS-1$
  public static final String SHX = "shx"; //$NON-NLS-1$

  public static final String SDAT = "sdat"; //$NON-NLS-1$
  public static final String SGRD = "sgrd"; //$NON-NLS-1$
  public static final String TFW = "tfw"; //$NON-NLS-1$
  public static final String TIF = "tif"; //$NON-NLS-1$
  public static final String TIFF = "tiff"; //$NON-NLS-1$
  public static final String TIFW = "tifw"; //$NON-NLS-1$
  public static final String WLD = "wld"; //$NON-NLS-1$
  public static final String XYZ = "xyz"; //$NON-NLS-1$
  public static final String ZIP = "zip"; //$NON-NLS-1$
  public static final String FLML = "flml"; //$NON-NLS-1$
  public static final String SQLITE = "sqlite"; //$NON-NLS-1$
  public static final String GPKG = "gpkg"; //$NON-NLS-1$
  public static final String TOPOJSON = "topojson"; //$NON-NLS-1$
  public static final String GEOJSON = "geojson"; //$NON-NLS-1$
  public static final String ESRIGEOJSON = "esrijson"; //$NON-NLS-1$
  public static final String MBTILES = "mbtiles"; //$NON-NLS-1$
  public static final String SQL = "sql"; //$NON-NLS-1$
  public static final String JSON = "json"; //$NON-NLS-1$

}
